@@ -4,7 +4,7 @@ import re
 from collections import OrderedDict, defaultdict
 from functools import partial
 from itertools import chain
-from typing import TYPE_CHECKING, Any, Dict, List, NamedTuple, Optional, Set, Tuple
+from typing import TYPE_CHECKING, Any, NamedTuple, TypedDict
 from warnings import warn
 
 from . import place
@@ -13,18 +13,16 @@ from .exceptions import MissingSection
 from .settings import DEFAULT_CONFIG, Config
 
 if TYPE_CHECKING:
-    from mypy_extensions import TypedDict
-
     CommentsAboveDict = TypedDict(
-        "CommentsAboveDict", {"straight": Dict[str, Any], "from": Dict[str, Any]}
+        "CommentsAboveDict", {"straight": dict[str, Any], "from": dict[str, Any]}
     )
 
     CommentsDict = TypedDict(
         "CommentsDict",
         {
-            "from": Dict[str, Any],
-            "straight": Dict[str, Any],
-            "nested": Dict[str, Any],
+            "from": dict[str, Any],
+            "straight": dict[str, Any],
+            "nested": dict[str, Any],
             "above": CommentsAboveDict,
         },
     )
@@ -38,7 +36,7 @@ def _infer_line_separator(contents: str) -> str:
     return "\n"
 
 
-def normalize_line(raw_line: str) -> Tuple[str, str]:
+def normalize_line(raw_line: str) -> tuple[str, str]:
     """Normalizes import related statements in the provided line.
 
     Returns (normalized_line: str, raw_line: str)
@@ -52,7 +50,7 @@ def normalize_line(raw_line: str) -> Tuple[str, str]:
     return line, raw_line
 
 
-def import_type(line: str, config: Config = DEFAULT_CONFIG) -> Optional[str]:
+def import_type(line: str, config: Config = DEFAULT_CONFIG) -> str | None:
     """If the current line is an import line it will return its type (from or straight)"""
     if config.honor_noqa and line.lower().rstrip().endswith("noqa"):
         return None
@@ -84,9 +82,9 @@ def skip_line(
     line: str,
     in_quote: str,
     index: int,
-    section_comments: Tuple[str, ...],
+    section_comments: tuple[str, ...],
     needs_import: bool = True,
-) -> Tuple[bool, str]:
+) -> tuple[bool, str]:
     """Determine if a given line should be skipped.
 
     Returns back a tuple containing:
@@ -127,22 +125,25 @@ def skip_line(
 
 
 class ParsedContent(NamedTuple):
-    in_lines: List[str]
-    lines_without_imports: List[str]
+    in_lines: list[str]
+    lines_without_imports: list[str]
     import_index: int
-    place_imports: Dict[str, List[str]]
-    import_placements: Dict[str, str]
-    as_map: Dict[str, Dict[str, List[str]]]
-    imports: Dict[str, Dict[str, Any]]
+    place_imports: dict[str, list[str]]
+    import_placements: dict[str, str]
+    as_map: dict[str, dict[str, list[str]]]
+    imports: dict[str, dict[str, Any]]
     categorized_comments: "CommentsDict"
     change_count: int
     original_line_count: int
     line_separator: str
     sections: Any
-    verbose_output: List[str]
-    trailing_commas: Set[str]
+    verbose_output: list[str]
+    trailing_commas: set[str]
 
 
+# Ignore DeepSource cyclomatic complexity check for this function. It is one
+# the main entrypoints so sort of expected to be complex.
+# skipcq: PY-R1000
 def file_contents(contents: str, config: Config = DEFAULT_CONFIG) -> ParsedContent:
     """Parses a python file taking out and categorizing imports."""
     line_separator: str = config.line_ending or _infer_line_separator(contents)
@@ -152,23 +153,18 @@ def file_contents(contents: str, config: Config = DEFAULT_CONFIG) -> ParsedConte
 
     out_lines = []
     original_line_count = len(in_lines)
-    if config.old_finders:
-        from .deprecated.finders import FindersManager
-
-        finder = FindersManager(config=config).find
-    else:
-        finder = partial(place.module, config=config)
+    finder = partial(place.module, config=config)
 
     line_count = len(in_lines)
 
-    place_imports: Dict[str, List[str]] = {}
-    import_placements: Dict[str, str] = {}
-    as_map: Dict[str, Dict[str, List[str]]] = {
+    place_imports: dict[str, list[str]] = {}
+    import_placements: dict[str, str] = {}
+    as_map: dict[str, dict[str, list[str]]] = {
         "straight": defaultdict(list),
         "from": defaultdict(list),
     }
-    imports: OrderedDict[str, Dict[str, Any]] = OrderedDict()
-    verbose_output: List[str] = []
+    imports: OrderedDict[str, dict[str, Any]] = OrderedDict()
+    verbose_output: list[str] = []
 
     for section in chain(config.sections, config.forced_separate):
         imports[section] = {"straight": OrderedDict(), "from": OrderedDict()}
@@ -179,7 +175,7 @@ def file_contents(contents: str, config: Config = DEFAULT_CONFIG) -> ParsedConte
         "above": {"straight": {}, "from": {}},
     }
 
-    trailing_commas: Set[str] = set()
+    trailing_commas: set[str] = set()
 
     index = 0
     import_index = -1
@@ -374,7 +370,7 @@ def file_contents(contents: str, config: Config = DEFAULT_CONFIG) -> ParsedConte
 
                 from_import = parts[0].split(" ")
                 import_string = (" cimport " if cimports else " import ").join(
-                    [from_import[0] + " " + "".join(from_import[1:])] + parts[1:]
+                    [from_import[0] + " " + "".join(from_import[1:]), *parts[1:]]
                 )
 
             just_imports = [
@@ -382,7 +378,7 @@ def file_contents(contents: str, config: Config = DEFAULT_CONFIG) -> ParsedConte
                 for item in strip_syntax(import_string).split()
             ]
 
-            attach_comments_to: Optional[List[Any]] = None
+            attach_comments_to: list[Any] | None = None
             direct_imports = just_imports[1:]
             straight_import = True
             top_level_module = ""
@@ -451,19 +447,20 @@ def file_contents(contents: str, config: Config = DEFAULT_CONFIG) -> ParsedConte
                 if placed_module == "":
                     warn(
                         f"could not place module {import_from} of line {line} --"
-                        " Do you need to define a default section?"
+                        " Do you need to define a default section?",
+                        stacklevel=2,
                     )
 
                 if placed_module and placed_module not in imports:
                     raise MissingSection(import_module=import_from, section=placed_module)
 
-                root = imports[placed_module][type_of_import]  # type: ignore
+                root = imports[placed_module][type_of_import]
                 for import_name in just_imports:
                     associated_comment = nested_comments.get(import_name)
                     if associated_comment:
-                        categorized_comments["nested"].setdefault(import_from, {})[
-                            import_name
-                        ] = associated_comment
+                        categorized_comments["nested"].setdefault(import_from, {})[import_name] = (
+                            associated_comment
+                        )
                         if associated_comment in comments:  # pragma: no branch
                             comments.pop(comments.index(associated_comment))
                 if (
@@ -493,7 +490,7 @@ def file_contents(contents: str, config: Config = DEFAULT_CONFIG) -> ParsedConte
                         and "isort:imports-" not in last
                         and "isort: imports-" not in last
                         and not config.treat_all_comments_as_code
-                        and not last.strip() in config.treat_comments_as_code
+                        and last.strip() not in config.treat_comments_as_code
                     ):
                         categorized_comments["above"]["from"].setdefault(import_from, []).insert(
                             0, out_lines.pop(-1)
@@ -545,7 +542,7 @@ def file_contents(contents: str, config: Config = DEFAULT_CONFIG) -> ParsedConte
                             and "isort:imports-" not in last
                             and "isort: imports-" not in last
                             and not config.treat_all_comments_as_code
-                            and not last.strip() in config.treat_comments_as_code
+                            and last.strip() not in config.treat_comments_as_code
                         ):
                             categorized_comments["above"]["straight"].setdefault(module, []).insert(
                                 0, out_lines.pop(-1)
@@ -569,17 +566,16 @@ def file_contents(contents: str, config: Config = DEFAULT_CONFIG) -> ParsedConte
                     if placed_module == "":
                         warn(
                             f"could not place module {module} of line {line} --"
-                            " Do you need to define a default section?"
+                            " Do you need to define a default section?",
+                            stacklevel=2,
                         )
                         imports.setdefault("", {"straight": OrderedDict(), "from": OrderedDict()})
 
                     if placed_module and placed_module not in imports:
                         raise MissingSection(import_module=module, section=placed_module)
 
-                    straight_import |= imports[placed_module][type_of_import].get(  # type: ignore
-                        module, False
-                    )
-                    imports[placed_module][type_of_import][module] = straight_import  # type: ignore
+                    straight_import |= imports[placed_module][type_of_import].get(module, False)
+                    imports[placed_module][type_of_import][module] = straight_import
 
     change_count = len(out_lines) - original_line_count
 
