@@ -896,7 +896,6 @@ else:  # 2.x
                 "profile": "",
                 "honor_noqa": False,
                 "src_paths": frozenset(),
-                "old_finders": False,
                 "remove_redundant_aliases": False,
                 "float_to_top": False,
                 "filter_files": False,
@@ -980,7 +979,6 @@ else:  # 2.x
         directory="/home/abuild/rpmbuild/BUILD/isort-5.11.0",
         profile="",
         honor_noqa=False,
-        old_finders=False,
         remove_redundant_aliases=False,
         float_to_top=False,
         filter_files=False,
@@ -1761,7 +1759,6 @@ def test_isort_is_idempotent(config: isort.Config, disregard_skip: bool) -> None
                 "profile": "",
                 "honor_noqa": False,
                 "src_paths": frozenset(),
-                "old_finders": False,
                 "remove_redundant_aliases": False,
                 "float_to_top": False,
                 "filter_files": False,
@@ -1845,7 +1842,6 @@ def test_isort_is_idempotent(config: isort.Config, disregard_skip: bool) -> None
         directory="/home/abuild/rpmbuild/BUILD/isort-5.11.0",
         profile="",
         honor_noqa=False,
-        old_finders=False,
         remove_redundant_aliases=False,
         float_to_top=False,
         filter_files=False,
